@@ -10,6 +10,7 @@ import yaml
 from sqlalchemy.exc import OperationalError
 from teradataml import DataFrame
 from teradataml.dataframe.copy_to import copy_to_sql
+import webbrowser
 
 import tdcsm
 from pathlib import Path
@@ -58,7 +59,7 @@ class tdcoa:
     systemspath = ''
     filesetpath = ''
     outputpath = ''
-    version = "0.3.9.3.0"
+    version = "0.3.9.4.0"
 
     # dictionaries
     secrets = {}
@@ -364,16 +365,19 @@ class tdcoa:
         # download any control files first (filesets.yaml, motd.txt, etc.)
         # motd
         giturl = githost + self.settings['gitmotd']
-        self.utils.log('downloading "motd.txt" from github')
+        self.utils.log('downloading "motd.html" from github')
         self.utils.log('  requesting url', giturl)
         if self.skipgit:
             self.utils.log('  setting: skip_git = True', 'skipping download')
             filecontent = 'default message'
         else:
             filecontent = requests.get(giturl).text
-        with open(os.path.join(self.approot, 'motd.txt'), 'w') as fh:
+        with open(os.path.join(self.approot, 'motd.html'), 'w') as fh:
             fh.write(filecontent)
 
+        file_url = 'file://' + os.path.join(self.approot, 'motd.html')
+        webbrowser.open(file_url)
+
         # filesets
         giturl = githost + self.settings['gitfileset']
         self.utils.log('downloading "filesets.yaml" from github')
